busby
=====

Parse a csv file and send through a websocket.

::

    Usage:
        busby <uri> <filename> <output_file> <username> <apikey>

    Options:
        busby --help
        busby --version

    Parameters:
        url: string
            the url to send the websocket to, exculding http://
        file: string
            the path to the file you would like to parse
        output_file: string
            the path to the file to save the results
        username: string
            username for authentication
        apikey: string
            apikey for authentication

